# tahini

|Service|Status|
| -------------: | :---- |
| Testing        | [![Python package](https://github.com/tahini-dev/tahini/workflows/Python%20package/badge.svg)](https://github.com/tahini-dev/tahini/actions?query=workflow%3A%22Python+package%22) |
| Coverage       | [![Codecov branch](https://img.shields.io/codecov/c/github/tahini-dev/tahini/master.svg)](https://codecov.io/gh/tahini-dev/tahini) |
| PyPI           | [![Upload Python Package](https://github.com/tahini-dev/tahini/workflows/Upload%20Python%20Package/badge.svg)](https://pypi.org/project/tahini/) |
| Docs           | [![docs](https://github.com/tahini-dev/tahini/workflows/docs/badge.svg)](https://tahini-dev.github.io/tahini/) |

Package for graph theory

## Goals

- Learn
- Have fun
- Write python implementation (classes) for graph theory, will use pandas for this is a start to make it easier
- Write graph theory algorithms
- Update to cython implementation for graph theory for speed